aggregateStates: merge segments that are all in a row, but avoid slopping...

View source: R/aggregateStates.R

aggregateStatesR Documentation

merge segments that are all in a row, but avoid slopping across chroms

Description

merge segments that are all in a row, but avoid slopping across chroms

Usage

aggregateStates(HMM, only3 = FALSE, verbose = FALSE, BPPARAM = SerialParam())

Arguments

HMM

a ChromHMM GRanges

only3

keep only 'name', 'thick', 'itemRgb' as mcols? (FALSE)

verbose

prattle endlessly about which contig we're on? (FALSE)

BPPARAM

BiocParallel object (default is SerialParam())

Value

HMM but without unnecessary segmentations (or mcols)


ttriche/chromophobe documentation built on Oct. 14, 2024, 11:59 a.m.